DmColors class
Typed color token bag — color scheme and extension tokens in one place.
Split into colorScheme (maps to Flutter ColorScheme) and extension (non-ColorScheme tokens via DmColorExtension).
- Annotations
Constructors
- DmColors({required ColorScheme colorScheme, required DmColorExtension extension})
-
Creates a DmColors with the given
colorSchemeandextension.const - DmColors.forest()
-
Returns the Forest (light) color tokens.
factory
- DmColors.moonlight()
-
Returns the Moonlight (dark) color tokens.
factory
- DmColors.ocean()
-
Returns the Ocean (dark) color tokens.
factory
- DmColors.sunshine()
-
Returns the Sunshine (light) color tokens.
factory
Properties
- colorScheme → ColorScheme
-
The Flutter ColorScheme for this token set.
final
- extension → DmColorExtension
-
The DuskMoon semantic color extension tokens.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited